componenttools.component_to_containment_signature
=================================================

.. autofunction:: abjad.tools.componenttools.component_to_containment_signature.component_to_containment_signature
